==> openshift-model-monitoring-6.1.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/TLSConfigFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.SecretKeySelector;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface TLSConfigFluent<A extends TLSConfigFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildCa instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretOrConfigMap getCa();
  public SecretOrConfigMap buildCa();
  public A withCa(SecretOrConfigMap ca);
  public Boolean hasCa();
  public TLSConfigFluent.CaNested<A> withNewCa();
  public TLSConfigFluent.CaNested<A> withNewCaLike(SecretOrConfigMap item);
  public TLSConfigFluent.CaNested<A> editCa();
  public TLSConfigFluent.CaNested<A> editOrNewCa();
  public TLSConfigFluent.CaNested<A> editOrNewCaLike(SecretOrConfigMap item);
  public String getCaFile();
  public A withCaFile(String caFile);
  public Boolean hasCaFile();
  
  /**
   * This method has been deprecated, please use method buildCert instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretOrConfigMap getCert();
  public SecretOrConfigMap buildCert();
  public A withCert(SecretOrConfigMap cert);
  public Boolean hasCert();
  public TLSConfigFluent.CertNested<A> withNewCert();
  public TLSConfigFluent.CertNested<A> withNewCertLike(SecretOrConfigMap item);
  public TLSConfigFluent.CertNested<A> editCert();
  public TLSConfigFluent.CertNested<A> editOrNewCert();
  public TLSConfigFluent.CertNested<A> editOrNewCertLike(SecretOrConfigMap item);
  public String getCertFile();
  public A withCertFile(String certFile);
  public Boolean hasCertFile();
  public Boolean getInsecureSkipVerify();
  public A withInsecureSkipVerify(Boolean insecureSkipVerify);
  public Boolean hasInsecureSkipVerify();
  public String getKeyFile();
  public A withKeyFile(String keyFile);
  public Boolean hasKeyFile();
  public SecretKeySelector getKeySecret();
  public A withKeySecret(SecretKeySelector keySecret);
  public Boolean hasKeySecret();
  public A withNewKeySecret(String key,String name,Boolean optional);
  public String getServerName();
  public A withServerName(String serverName);
  public Boolean hasServerName();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withInsecureSkipVerify();
  public interface CaNested<N> extends Nested<N>,SecretOrConfigMapFluent<TLSConfigFluent.CaNested<N>>{
    public N and();
    public N endCa();
    
  }
  public interface CertNested<N> extends Nested<N>,SecretOrConfigMapFluent<TLSConfigFluent.CertNested<N>>{
    public N and();
    public N endCert();
    
  }
  
}

==> openshift-model-monitoring-6.7.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/TLSConfigFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.SecretKeySelector;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface TLSConfigFluent<A extends TLSConfigFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildCa instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretOrConfigMap getCa();
  public SecretOrConfigMap buildCa();
  public A withCa(SecretOrConfigMap ca);
  public Boolean hasCa();
  public TLSConfigFluent.CaNested<A> withNewCa();
  public TLSConfigFluent.CaNested<A> withNewCaLike(SecretOrConfigMap item);
  public TLSConfigFluent.CaNested<A> editCa();
  public TLSConfigFluent.CaNested<A> editOrNewCa();
  public TLSConfigFluent.CaNested<A> editOrNewCaLike(SecretOrConfigMap item);
  public String getCaFile();
  public A withCaFile(String caFile);
  public Boolean hasCaFile();
  
  /**
   * This method has been deprecated, please use method buildCert instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretOrConfigMap getCert();
  public SecretOrConfigMap buildCert();
  public A withCert(SecretOrConfigMap cert);
  public Boolean hasCert();
  public TLSConfigFluent.CertNested<A> withNewCert();
  public TLSConfigFluent.CertNested<A> withNewCertLike(SecretOrConfigMap item);
  public TLSConfigFluent.CertNested<A> editCert();
  public TLSConfigFluent.CertNested<A> editOrNewCert();
  public TLSConfigFluent.CertNested<A> editOrNewCertLike(SecretOrConfigMap item);
  public String getCertFile();
  public A withCertFile(String certFile);
  public Boolean hasCertFile();
  public Boolean getInsecureSkipVerify();
  public A withInsecureSkipVerify(Boolean insecureSkipVerify);
  public Boolean hasInsecureSkipVerify();
  public String getKeyFile();
  public A withKeyFile(String keyFile);
  public Boolean hasKeyFile();
  public SecretKeySelector getKeySecret();
  public A withKeySecret(SecretKeySelector keySecret);
  public Boolean hasKeySecret();
  public A withNewKeySecret(String key,String name,Boolean optional);
  public String getServerName();
  public A withServerName(String serverName);
  public Boolean hasServerName();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withInsecureSkipVerify();
  public interface CaNested<N> extends Nested<N>,SecretOrConfigMapFluent<TLSConfigFluent.CaNested<N>>{
    public N and();
    public N endCa();
    
  }
  public interface CertNested<N> extends Nested<N>,SecretOrConfigMapFluent<TLSConfigFluent.CertNested<N>>{
    public N and();
    public N endCert();
    
  }
  
}
